Class: Google::Apis::BloggerV3::BloggerService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::BloggerV3::BloggerService
- Defined in:
- lib/google/apis/blogger_v3/service.rb
Overview
blogger API
The Blogger API provides access to posts, comments and pages of a Blogger blog.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://blogger.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#approve_comment(blog_id, post_id, comment_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Comment
Marks a comment as not spam by blog id, post id and comment id.
-
#delete_comment(blog_id, post_id, comment_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
Deletes a comment by blog id, post id and comment id.
-
#delete_page(blog_id, page_id, use_trash: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
Deletes a page by blog id and page id.
-
#delete_post(blog_id, post_id, use_trash: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
Deletes a post by blog id and post id.
-
#get_blog(blog_id, max_posts: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Blog
Gets a blog by id.
-
#get_blog_by_url(url, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Blog
Gets a blog by url.
-
#get_blog_user_info(user_id, blog_id, max_posts: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::BlogUserInfo
Gets one blog and user info pair by blog id and user id.
-
#get_comment(blog_id, post_id, comment_id, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Comment
Gets a comment by id.
-
#get_page(blog_id, page_id, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Page
Gets a page by blog id and page id.
-
#get_page_view(blog_id, range: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Pageviews
Gets page views by blog id.
-
#get_post(blog_id, post_id, fetch_body: nil, fetch_images: nil, max_comments: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Post
Gets a post by blog id and post id.
-
#get_post_by_path(blog_id, path, max_comments: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Post
Gets a post by path.
-
#get_post_user_info(user_id, blog_id, post_id, max_comments: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::PostUserInfo
Gets one post and user info pair, by post_id and user_id.
-
#get_user(user_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::User
Gets one user by user_id.
-
#initialize ⇒ BloggerService
constructor
A new instance of BloggerService.
-
#insert_page(blog_id, page_object = nil, is_draft: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Page
Inserts a page.
-
#insert_post(blog_id, post_object = nil, fetch_body: nil, fetch_images: nil, is_draft: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Post
Inserts a post.
-
#list_blogs_by_user(user_id, fetch_user_info: nil, role: nil, status: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::BlogList
Lists blogs by user.
-
#list_comments(blog_id, post_id, end_date: nil, fetch_bodies: nil, max_results: nil, page_token: nil, start_date: nil, status: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::CommentList
Lists comments.
-
#list_comments_by_blog(blog_id, end_date: nil, fetch_bodies: nil, max_results: nil, page_token: nil, start_date: nil, status: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::CommentList
Lists comments by blog.
-
#list_pages(blog_id, fetch_bodies: nil, max_results: nil, page_token: nil, status: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::PageList
Lists pages.
-
#list_post_user_info(user_id, blog_id, end_date: nil, fetch_bodies: nil, labels: nil, max_results: nil, order_by: nil, page_token: nil, start_date: nil, status: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::PostUserInfosList
Lists post and user info pairs.
-
#list_posts(blog_id, end_date: nil, fetch_bodies: nil, fetch_images: nil, labels: nil, max_results: nil, order_by: nil, page_token: nil, sort_option: nil, start_date: nil, status: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::PostList
Lists posts.
-
#mark_comment_as_spam(blog_id, post_id, comment_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Comment
Marks a comment as spam by blog id, post id and comment id.
-
#patch_page(blog_id, page_id, page_object = nil, publish: nil, revert: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Page
Patches a page.
-
#patch_post(blog_id, post_id, post_object = nil, fetch_body: nil, fetch_images: nil, max_comments: nil, publish: nil, revert: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Post
Patches a post.
-
#publish_page(blog_id, page_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Page
Publishes a page.
-
#publish_post(blog_id, post_id, publish_date: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Post
Publishes a post.
-
#remove_comment_content(blog_id, post_id, comment_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Comment
Removes the content of a comment by blog id, post id and comment id.
-
#revert_page(blog_id, page_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Page
Reverts a published or scheduled page to draft state.
-
#revert_post(blog_id, post_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Post
Reverts a published or scheduled post to draft state.
-
#search_posts(blog_id, q, fetch_bodies: nil, order_by: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::PostList
Searches for posts matching given query terms in the specified blog.
-
#update_page(blog_id, page_id, page_object = nil, publish: nil, revert: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Page
Updates a page by blog id and page id.
-
#update_post(blog_id, post_id, post_object = nil, fetch_body: nil, fetch_images: nil, max_comments: nil, publish: nil, revert: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Post
Updates a post by blog id and post id.
Constructor Details
#initialize ⇒ BloggerService
Returns a new instance of BloggerService.
47 48 49 50 51 52 |
# File 'lib/google/apis/blogger_v3/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-blogger_v3', client_version: Google::Apis::BloggerV3::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/blogger_v3/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/blogger_v3/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#approve_comment(blog_id, post_id, comment_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Comment
Marks a comment as not spam by blog id, post id and comment id.
213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/google/apis/blogger_v3/service.rb', line 213 def approve_comment(blog_id, post_id, comment_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v3/blogs/{blogId}/posts/{postId}/comments/{commentId}/approve', ) command.response_representation = Google::Apis::BloggerV3::Comment::Representation command.response_class = Google::Apis::BloggerV3::Comment command.params['blogId'] = blog_id unless blog_id.nil? command.params['postId'] = post_id unless post_id.nil? command.params['commentId'] = comment_id unless comment_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_comment(blog_id, post_id, comment_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
This method returns an undefined value.
Deletes a comment by blog id, post id and comment id.
246 247 248 249 250 251 252 253 254 |
# File 'lib/google/apis/blogger_v3/service.rb', line 246 def delete_comment(blog_id, post_id, comment_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v3/blogs/{blogId}/posts/{postId}/comments/{commentId}', ) command.params['blogId'] = blog_id unless blog_id.nil? command.params['postId'] = post_id unless post_id.nil? command.params['commentId'] = comment_id unless comment_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_page(blog_id, page_id, use_trash: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
This method returns an undefined value.
Deletes a page by blog id and page id.
496 497 498 499 500 501 502 503 504 |
# File 'lib/google/apis/blogger_v3/service.rb', line 496 def delete_page(blog_id, page_id, use_trash: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v3/blogs/{blogId}/pages/{pageId}', ) command.params['blogId'] = blog_id unless blog_id.nil? command.params['pageId'] = page_id unless page_id.nil? command.query['useTrash'] = use_trash unless use_trash.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_post(blog_id, post_id, use_trash: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
This method returns an undefined value.
Deletes a post by blog id and post id.
856 857 858 859 860 861 862 863 864 |
# File 'lib/google/apis/blogger_v3/service.rb', line 856 def delete_post(blog_id, post_id, use_trash: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v3/blogs/{blogId}/posts/{postId}', ) command.params['blogId'] = blog_id unless blog_id.nil? command.params['postId'] = post_id unless post_id.nil? command.query['useTrash'] = use_trash unless use_trash.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_blog(blog_id, max_posts: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Blog
Gets a blog by id.
109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/google/apis/blogger_v3/service.rb', line 109 def get_blog(blog_id, max_posts: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3/blogs/{blogId}', ) command.response_representation = Google::Apis::BloggerV3::Blog::Representation command.response_class = Google::Apis::BloggerV3::Blog command.params['blogId'] = blog_id unless blog_id.nil? command.query['maxPosts'] = max_posts unless max_posts.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_blog_by_url(url, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Blog
Gets a blog by url.
142 143 144 145 146 147 148 149 150 151 |
# File 'lib/google/apis/blogger_v3/service.rb', line 142 def get_blog_by_url(url, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3/blogs/byurl', ) command.response_representation = Google::Apis::BloggerV3::Blog::Representation command.response_class = Google::Apis::BloggerV3::Blog command.query['url'] = url unless url.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_blog_user_info(user_id, blog_id, max_posts: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::BlogUserInfo
Gets one blog and user info pair by blog id and user id.
75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/google/apis/blogger_v3/service.rb', line 75 def get_blog_user_info(user_id, blog_id, max_posts: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3/users/{userId}/blogs/{blogId}', ) command.response_representation = Google::Apis::BloggerV3::BlogUserInfo::Representation command.response_class = Google::Apis::BloggerV3::BlogUserInfo command.params['userId'] = user_id unless user_id.nil? command.params['blogId'] = blog_id unless blog_id.nil? command.query['maxPosts'] = max_posts unless max_posts.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_comment(blog_id, post_id, comment_id, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Comment
Gets a comment by id.
278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/google/apis/blogger_v3/service.rb', line 278 def get_comment(blog_id, post_id, comment_id, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3/blogs/{blogId}/posts/{postId}/comments/{commentId}', ) command.response_representation = Google::Apis::BloggerV3::Comment::Representation command.response_class = Google::Apis::BloggerV3::Comment command.params['blogId'] = blog_id unless blog_id.nil? command.params['postId'] = post_id unless post_id.nil? command.params['commentId'] = comment_id unless comment_id.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_page(blog_id, page_id, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Page
Gets a page by blog id and page id.
527 528 529 530 531 532 533 534 535 536 537 |
# File 'lib/google/apis/blogger_v3/service.rb', line 527 def get_page(blog_id, page_id, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3/blogs/{blogId}/pages/{pageId}', ) command.response_representation = Google::Apis::BloggerV3::Page::Representation command.response_class = Google::Apis::BloggerV3::Page command.params['blogId'] = blog_id unless blog_id.nil? command.params['pageId'] = page_id unless page_id.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_page_view(blog_id, range: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Pageviews
Gets page views by blog id.
463 464 465 466 467 468 469 470 471 472 |
# File 'lib/google/apis/blogger_v3/service.rb', line 463 def get_page_view(blog_id, range: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3/blogs/{blogId}/pageviews', ) command.response_representation = Google::Apis::BloggerV3::Pageviews::Representation command.response_class = Google::Apis::BloggerV3::Pageviews command.params['blogId'] = blog_id unless blog_id.nil? command.query['range'] = range unless range.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_post(blog_id, post_id, fetch_body: nil, fetch_images: nil, max_comments: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Post
Gets a post by blog id and post id
890 891 892 893 894 895 896 897 898 899 900 901 902 903 |
# File 'lib/google/apis/blogger_v3/service.rb', line 890 def get_post(blog_id, post_id, fetch_body: nil, fetch_images: nil, max_comments: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3/blogs/{blogId}/posts/{postId}', ) command.response_representation = Google::Apis::BloggerV3::Post::Representation command.response_class = Google::Apis::BloggerV3::Post command.params['blogId'] = blog_id unless blog_id.nil? command.params['postId'] = post_id unless post_id.nil? command.query['fetchBody'] = fetch_body unless fetch_body.nil? command.query['fetchImages'] = fetch_images unless fetch_images.nil? command.query['maxComments'] = max_comments unless max_comments.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_post_by_path(blog_id, path, max_comments: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Post
Gets a post by path.
927 928 929 930 931 932 933 934 935 936 937 938 |
# File 'lib/google/apis/blogger_v3/service.rb', line 927 def get_post_by_path(blog_id, path, max_comments: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3/blogs/{blogId}/posts/bypath', ) command.response_representation = Google::Apis::BloggerV3::Post::Representation command.response_class = Google::Apis::BloggerV3::Post command.params['blogId'] = blog_id unless blog_id.nil? command.query['maxComments'] = max_comments unless max_comments.nil? command.query['path'] = path unless path.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_post_user_info(user_id, blog_id, post_id, max_comments: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::PostUserInfo
Gets one post and user info pair, by post_id and user_id.
772 773 774 775 776 777 778 779 780 781 782 783 |
# File 'lib/google/apis/blogger_v3/service.rb', line 772 def get_post_user_info(user_id, blog_id, post_id, max_comments: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3/users/{userId}/blogs/{blogId}/posts/{postId}', ) command.response_representation = Google::Apis::BloggerV3::PostUserInfo::Representation command.response_class = Google::Apis::BloggerV3::PostUserInfo command.params['userId'] = user_id unless user_id.nil? command.params['blogId'] = blog_id unless blog_id.nil? command.params['postId'] = post_id unless post_id.nil? command.query['maxComments'] = max_comments unless max_comments.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_user(user_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::User
Gets one user by user_id.
1236 1237 1238 1239 1240 1241 1242 1243 1244 |
# File 'lib/google/apis/blogger_v3/service.rb', line 1236 def get_user(user_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3/users/{userId}', ) command.response_representation = Google::Apis::BloggerV3::User::Representation command.response_class = Google::Apis::BloggerV3::User command.params['userId'] = user_id unless user_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#insert_page(blog_id, page_object = nil, is_draft: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Page
Inserts a page.
560 561 562 563 564 565 566 567 568 569 570 571 |
# File 'lib/google/apis/blogger_v3/service.rb', line 560 def insert_page(blog_id, page_object = nil, is_draft: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v3/blogs/{blogId}/pages', ) command.request_representation = Google::Apis::BloggerV3::Page::Representation command.request_object = page_object command.response_representation = Google::Apis::BloggerV3::Page::Representation command.response_class = Google::Apis::BloggerV3::Page command.params['blogId'] = blog_id unless blog_id.nil? command.query['isDraft'] = is_draft unless is_draft.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#insert_post(blog_id, post_object = nil, fetch_body: nil, fetch_images: nil, is_draft: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Post
Inserts a post.
963 964 965 966 967 968 969 970 971 972 973 974 975 976 |
# File 'lib/google/apis/blogger_v3/service.rb', line 963 def insert_post(blog_id, post_object = nil, fetch_body: nil, fetch_images: nil, is_draft: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v3/blogs/{blogId}/posts', ) command.request_representation = Google::Apis::BloggerV3::Post::Representation command.request_object = post_object command.response_representation = Google::Apis::BloggerV3::Post::Representation command.response_class = Google::Apis::BloggerV3::Post command.params['blogId'] = blog_id unless blog_id.nil? command.query['fetchBody'] = fetch_body unless fetch_body.nil? command.query['fetchImages'] = fetch_images unless fetch_images.nil? command.query['isDraft'] = is_draft unless is_draft.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_blogs_by_user(user_id, fetch_user_info: nil, role: nil, status: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::BlogList
Lists blogs by user.
178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/google/apis/blogger_v3/service.rb', line 178 def list_blogs_by_user(user_id, fetch_user_info: nil, role: nil, status: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3/users/{userId}/blogs', ) command.response_representation = Google::Apis::BloggerV3::BlogList::Representation command.response_class = Google::Apis::BloggerV3::BlogList command.params['userId'] = user_id unless user_id.nil? command.query['fetchUserInfo'] = fetch_user_info unless fetch_user_info.nil? command.query['role'] = role unless role.nil? command.query['status'] = status unless status.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_comments(blog_id, post_id, end_date: nil, fetch_bodies: nil, max_results: nil, page_token: nil, start_date: nil, status: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::CommentList
Lists comments.
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/google/apis/blogger_v3/service.rb', line 318 def list_comments(blog_id, post_id, end_date: nil, fetch_bodies: nil, max_results: nil, page_token: nil, start_date: nil, status: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3/blogs/{blogId}/posts/{postId}/comments', ) command.response_representation = Google::Apis::BloggerV3::CommentList::Representation command.response_class = Google::Apis::BloggerV3::CommentList command.params['blogId'] = blog_id unless blog_id.nil? command.params['postId'] = post_id unless post_id.nil? command.query['endDate'] = end_date unless end_date.nil? command.query['fetchBodies'] = fetch_bodies unless fetch_bodies.nil? command.query['maxResults'] = max_results unless max_results.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['startDate'] = start_date unless start_date.nil? command.query['status'] = status unless status.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_comments_by_blog(blog_id, end_date: nil, fetch_bodies: nil, max_results: nil, page_token: nil, start_date: nil, status: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::CommentList
Lists comments by blog.
361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 |
# File 'lib/google/apis/blogger_v3/service.rb', line 361 def list_comments_by_blog(blog_id, end_date: nil, fetch_bodies: nil, max_results: nil, page_token: nil, start_date: nil, status: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3/blogs/{blogId}/comments', ) command.response_representation = Google::Apis::BloggerV3::CommentList::Representation command.response_class = Google::Apis::BloggerV3::CommentList command.params['blogId'] = blog_id unless blog_id.nil? command.query['endDate'] = end_date unless end_date.nil? command.query['fetchBodies'] = fetch_bodies unless fetch_bodies.nil? command.query['maxResults'] = max_results unless max_results.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['startDate'] = start_date unless start_date.nil? command.query['status'] = status unless status.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_pages(blog_id, fetch_bodies: nil, max_results: nil, page_token: nil, status: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::PageList
Lists pages.
597 598 599 600 601 602 603 604 605 606 607 608 609 610 |
# File 'lib/google/apis/blogger_v3/service.rb', line 597 def list_pages(blog_id, fetch_bodies: nil, max_results: nil, page_token: nil, status: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3/blogs/{blogId}/pages', ) command.response_representation = Google::Apis::BloggerV3::PageList::Representation command.response_class = Google::Apis::BloggerV3::PageList command.params['blogId'] = blog_id unless blog_id.nil? command.query['fetchBodies'] = fetch_bodies unless fetch_bodies.nil? command.query['maxResults'] = max_results unless max_results.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['status'] = status unless status.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_post_user_info(user_id, blog_id, end_date: nil, fetch_bodies: nil, labels: nil, max_results: nil, order_by: nil, page_token: nil, start_date: nil, status: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::PostUserInfosList
Lists post and user info pairs.
814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 |
# File 'lib/google/apis/blogger_v3/service.rb', line 814 def list_post_user_info(user_id, blog_id, end_date: nil, fetch_bodies: nil, labels: nil, max_results: nil, order_by: nil, page_token: nil, start_date: nil, status: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3/users/{userId}/blogs/{blogId}/posts', ) command.response_representation = Google::Apis::BloggerV3::PostUserInfosList::Representation command.response_class = Google::Apis::BloggerV3::PostUserInfosList command.params['userId'] = user_id unless user_id.nil? command.params['blogId'] = blog_id unless blog_id.nil? command.query['endDate'] = end_date unless end_date.nil? command.query['fetchBodies'] = fetch_bodies unless fetch_bodies.nil? command.query['labels'] = labels unless labels.nil? command.query['maxResults'] = max_results unless max_results.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['startDate'] = start_date unless start_date.nil? command.query['status'] = status unless status.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_posts(blog_id, end_date: nil, fetch_bodies: nil, fetch_images: nil, labels: nil, max_results: nil, order_by: nil, page_token: nil, sort_option: nil, start_date: nil, status: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::PostList
Lists posts.
1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 |
# File 'lib/google/apis/blogger_v3/service.rb', line 1009 def list_posts(blog_id, end_date: nil, fetch_bodies: nil, fetch_images: nil, labels: nil, max_results: nil, order_by: nil, page_token: nil, sort_option: nil, start_date: nil, status: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3/blogs/{blogId}/posts', ) command.response_representation = Google::Apis::BloggerV3::PostList::Representation command.response_class = Google::Apis::BloggerV3::PostList command.params['blogId'] = blog_id unless blog_id.nil? command.query['endDate'] = end_date unless end_date.nil? command.query['fetchBodies'] = fetch_bodies unless fetch_bodies.nil? command.query['fetchImages'] = fetch_images unless fetch_images.nil? command.query['labels'] = labels unless labels.nil? command.query['maxResults'] = max_results unless max_results.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['sortOption'] = sort_option unless sort_option.nil? command.query['startDate'] = start_date unless start_date.nil? command.query['status'] = status unless status.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#mark_comment_as_spam(blog_id, post_id, comment_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Comment
Marks a comment as spam by blog id, post id and comment id.
398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/google/apis/blogger_v3/service.rb', line 398 def mark_comment_as_spam(blog_id, post_id, comment_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v3/blogs/{blogId}/posts/{postId}/comments/{commentId}/spam', ) command.response_representation = Google::Apis::BloggerV3::Comment::Representation command.response_class = Google::Apis::BloggerV3::Comment command.params['blogId'] = blog_id unless blog_id.nil? command.params['postId'] = post_id unless post_id.nil? command.params['commentId'] = comment_id unless comment_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_page(blog_id, page_id, page_object = nil, publish: nil, revert: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Page
Patches a page.
635 636 637 638 639 640 641 642 643 644 645 646 647 648 |
# File 'lib/google/apis/blogger_v3/service.rb', line 635 def patch_page(blog_id, page_id, page_object = nil, publish: nil, revert: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v3/blogs/{blogId}/pages/{pageId}', ) command.request_representation = Google::Apis::BloggerV3::Page::Representation command.request_object = page_object command.response_representation = Google::Apis::BloggerV3::Page::Representation command.response_class = Google::Apis::BloggerV3::Page command.params['blogId'] = blog_id unless blog_id.nil? command.params['pageId'] = page_id unless page_id.nil? command.query['publish'] = publish unless publish.nil? command.query['revert'] = revert unless revert.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_post(blog_id, post_id, post_object = nil, fetch_body: nil, fetch_images: nil, max_comments: nil, publish: nil, revert: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Post
Patches a post.
1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 |
# File 'lib/google/apis/blogger_v3/service.rb', line 1056 def patch_post(blog_id, post_id, post_object = nil, fetch_body: nil, fetch_images: nil, max_comments: nil, publish: nil, revert: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v3/blogs/{blogId}/posts/{postId}', ) command.request_representation = Google::Apis::BloggerV3::Post::Representation command.request_object = post_object command.response_representation = Google::Apis::BloggerV3::Post::Representation command.response_class = Google::Apis::BloggerV3::Post command.params['blogId'] = blog_id unless blog_id.nil? command.params['postId'] = post_id unless post_id.nil? command.query['fetchBody'] = fetch_body unless fetch_body.nil? command.query['fetchImages'] = fetch_images unless fetch_images.nil? command.query['maxComments'] = max_comments unless max_comments.nil? command.query['publish'] = publish unless publish.nil? command.query['revert'] = revert unless revert.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#publish_page(blog_id, page_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Page
Publishes a page.
670 671 672 673 674 675 676 677 678 679 |
# File 'lib/google/apis/blogger_v3/service.rb', line 670 def publish_page(blog_id, page_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v3/blogs/{blogId}/pages/{pageId}/publish', ) command.response_representation = Google::Apis::BloggerV3::Page::Representation command.response_class = Google::Apis::BloggerV3::Page command.params['blogId'] = blog_id unless blog_id.nil? command.params['pageId'] = page_id unless page_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#publish_post(blog_id, post_id, publish_date: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Post
Publishes a post.
1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/google/apis/blogger_v3/service.rb', line 1095 def publish_post(blog_id, post_id, publish_date: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v3/blogs/{blogId}/posts/{postId}/publish', ) command.response_representation = Google::Apis::BloggerV3::Post::Representation command.response_class = Google::Apis::BloggerV3::Post command.params['blogId'] = blog_id unless blog_id.nil? command.params['postId'] = post_id unless post_id.nil? command.query['publishDate'] = publish_date unless publish_date.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#remove_comment_content(blog_id, post_id, comment_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Comment
Removes the content of a comment by blog id, post id and comment id.
431 432 433 434 435 436 437 438 439 440 441 |
# File 'lib/google/apis/blogger_v3/service.rb', line 431 def remove_comment_content(blog_id, post_id, comment_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v3/blogs/{blogId}/posts/{postId}/comments/{commentId}/removecontent', ) command.response_representation = Google::Apis::BloggerV3::Comment::Representation command.response_class = Google::Apis::BloggerV3::Comment command.params['blogId'] = blog_id unless blog_id.nil? command.params['postId'] = post_id unless post_id.nil? command.params['commentId'] = comment_id unless comment_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#revert_page(blog_id, page_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Page
Reverts a published or scheduled page to draft state.
701 702 703 704 705 706 707 708 709 710 |
# File 'lib/google/apis/blogger_v3/service.rb', line 701 def revert_page(blog_id, page_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v3/blogs/{blogId}/pages/{pageId}/revert', ) command.response_representation = Google::Apis::BloggerV3::Page::Representation command.response_class = Google::Apis::BloggerV3::Page command.params['blogId'] = blog_id unless blog_id.nil? command.params['pageId'] = page_id unless page_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#revert_post(blog_id, post_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Post
Reverts a published or scheduled post to draft state.
1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 |
# File 'lib/google/apis/blogger_v3/service.rb', line 1127 def revert_post(blog_id, post_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v3/blogs/{blogId}/posts/{postId}/revert', ) command.response_representation = Google::Apis::BloggerV3::Post::Representation command.response_class = Google::Apis::BloggerV3::Post command.params['blogId'] = blog_id unless blog_id.nil? command.params['postId'] = post_id unless post_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#search_posts(blog_id, q, fetch_bodies: nil, order_by: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::PostList
Searches for posts matching given query terms in the specified blog.
1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 |
# File 'lib/google/apis/blogger_v3/service.rb', line 1160 def search_posts(blog_id, q, fetch_bodies: nil, order_by: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v3/blogs/{blogId}/posts/search', ) command.response_representation = Google::Apis::BloggerV3::PostList::Representation command.response_class = Google::Apis::BloggerV3::PostList command.params['blogId'] = blog_id unless blog_id.nil? command.query['fetchBodies'] = fetch_bodies unless fetch_bodies.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['q'] = q unless q.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_page(blog_id, page_id, page_object = nil, publish: nil, revert: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Page
Updates a page by blog id and page id.
735 736 737 738 739 740 741 742 743 744 745 746 747 748 |
# File 'lib/google/apis/blogger_v3/service.rb', line 735 def update_page(blog_id, page_id, page_object = nil, publish: nil, revert: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:put, 'v3/blogs/{blogId}/pages/{pageId}', ) command.request_representation = Google::Apis::BloggerV3::Page::Representation command.request_object = page_object command.response_representation = Google::Apis::BloggerV3::Page::Representation command.response_class = Google::Apis::BloggerV3::Page command.params['blogId'] = blog_id unless blog_id.nil? command.params['pageId'] = page_id unless page_id.nil? command.query['publish'] = publish unless publish.nil? command.query['revert'] = revert unless revert.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_post(blog_id, post_id, post_object = nil, fetch_body: nil, fetch_images: nil, max_comments: nil, publish: nil, revert: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BloggerV3::Post
Updates a post by blog id and post id.
1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 |
# File 'lib/google/apis/blogger_v3/service.rb', line 1199 def update_post(blog_id, post_id, post_object = nil, fetch_body: nil, fetch_images: nil, max_comments: nil, publish: nil, revert: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:put, 'v3/blogs/{blogId}/posts/{postId}', ) command.request_representation = Google::Apis::BloggerV3::Post::Representation command.request_object = post_object command.response_representation = Google::Apis::BloggerV3::Post::Representation command.response_class = Google::Apis::BloggerV3::Post command.params['blogId'] = blog_id unless blog_id.nil? command.params['postId'] = post_id unless post_id.nil? command.query['fetchBody'] = fetch_body unless fetch_body.nil? command.query['fetchImages'] = fetch_images unless fetch_images.nil? command.query['maxComments'] = max_comments unless max_comments.nil? command.query['publish'] = publish unless publish.nil? command.query['revert'] = revert unless revert.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |